Skip to contents

Thin AlgAware-specific wrapper around create_pie_map. Draws a pie chart at each station showing the relative carbon biomass contributed by Diatoms, Dinoflagellates, Cyanobacteria, Cryptophytes, Mesodinium spp., Silicoflagellates, and Other.

Usage

create_group_map(station_summary, phyto_groups, r_lat = 0.28)

Arguments

station_summary

Aggregated station data from aggregate_station_data(), containing columns name, AphiaID, carbon_ug_per_liter, STATION_NAME_SHORT, LATITUDE_WGS84_SWEREF99_DD, and LONGITUDE_WGS84_SWEREF99_DD.

phyto_groups

Data frame with columns name, AphiaID, and phyto_group as returned by SHARK4R::assign_phytoplankton_group().

r_lat

Pie chart radius in latitude degrees (default 0.28).

Value

A ggplot object.