Skip to contents

Like read_lims_data() but matches against all standard monitoring stations instead of just AlgAware stations.

Usage

read_lims_data_all(lims_path, station_mapper, standard_stations)

Arguments

lims_path

Path to LIMS data.txt file.

station_mapper

Data frame from load_station_mapper().

standard_stations

Data frame from load_standard_stations().

Value

A data.frame with columns: canonical_name, region, sample_date, sample_month, DEPH, CPHL, latitude, longitude. NULL if file not found or no valid data.